@@ -50,9 +50,9 @@ sub reset {
   my %options = @_;
 
   $options{name} ||= 'Simple';
-  $options{dir} ||= File::Temp::tempdir(
-    DIR => File::Spec->tmpdir, CLEANUP => 1
-  );
+  $options{dir} ||= File::Spec->rel2abs(File::Temp::tempdir(
+    DIR => File::Spec->curdir, CLEANUP => 1
+  ));
 
   my %data = (
     %options,
@@ -120,7 +120,7 @@ sub _gen_default_filedata {
       package $module_name;
 
       use vars qw( \$VERSION );
-      \$VERSION = '0.01';
+      \$VERSION = '0.001';
 
       use strict;
 
